#
# spec file for package kupfer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kupfer
Version:        322
Release:        2.6
Summary:        An interface for access to applications and documents
License:        GPL-3.0-or-later
Group:          System/X11/Utilities
URL:            https://kupferlauncher.github.io/
Source:         https://github.com/kupferlauncher/%{name}/archive/refs/tags/v%{version}.tar.gz#/%{name}-v%{version}.tar.gz
BuildRequires:  dbus-1-python3
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  gobject-introspection
BuildRequires:  intltool
BuildRequires:  python3 >= 3.4
BuildRequires:  python3-docutils
BuildRequires:  python3-gobject
BuildRequires:  python3-gobject-Gdk
BuildRequires:  python3-libxml2
BuildRequires:  python3-pyxdg
BuildRequires:  update-desktop-files
BuildRequires:  xml2po
Requires:       desktop-file-utils
Requires:       gvfs
Requires:       python3-cairo
Requires:       python3-dbus-python
Requires:       python3-docutils
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-libxml2
Requires:       python3-pyxdg
Requires(post): hicolor-icon-theme
Requires(post): shared-mime-info
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): shared-mime-info
Requires(postun): update-desktop-files
BuildArch:      noarch

%description
Kupfer is an interface for access to applications
and their documents.

The most typical use is to find a specific application and launch it.
Kupfer can be extended with plugins so that its quick-access
paradigm can be extended to many more objects than just
applications.

%prep
%autosetup -n %{name}-%{version}

%build
./waf configure --prefix=%{_prefix} --libdir=%{_libdir}
./waf build %{?_smp_mflags}

%install
./waf install --destdir=%{buildroot}
%suse_update_desktop_file %{name} GTK X-SuSE-DesktopUtility
%fdupes %{buildroot}

%find_lang %{name}

%files -f %{name}.lang
%license COPYING
%doc README.rst Documentation/*
%{_bindir}/%{name}
%{_bindir}/%{name}-exec
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/%{name}-exec.desktop
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/mime/packages/%{name}-mimetypes.xml
%{_datadir}/Thunar
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_mandir}/man1/%{name}-exec.1%{?ext_man}

%changelog
* Sat Feb  3 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop python-base BuildRequires: python2 is not used to build this
  package.
- Add gobject-introspection BuildRequires: automatically and
  properly detect typelib() dependnecies.
- Drop now auto-detected typelib-1_0-Gtk-3_0,
  typelib-1_0-Keybinder-3_0, and typelib-1_0-Wnck-3_0 dependencies.
* Tue Mar  7 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version v322
  * Update translations
  * Add support mate-dictionary in dictionary plugin
  * Fix Firefox and Thunderbird database connection
  * Add support for file://<local-hostname>/ URLs
  * Add Firefox tags plugin
  * Fix Thunderbird plugin
  * Add libvirt plugin - manage libvirt domains
  * Add zeal plugin - quick search in zeal docsets
  * Fix window plugin - don't break on Wayland, fix switching workspace
  * Fix segfault on Wayland and newer version of libwnck
* Sat Sep 11 2021 IBBoard <dev@ibboard.co.uk>
- Fix Python XDG dependency so that Kupfer doesn't crash on start
* Wed Aug 18 2021 Dr. Werner Fink <werner@suse.de>
- Require missed python3-libxml2 to get it build
* Wed Jul 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire python3 instead of python: this package moved to
  py3 long ago and the 'python' symbol is python2.
* Tue Feb 25 2020 wnereiz@member.fsf.org
- Add dependency packages python-base to satisfy waf env setting
* Sat Oct  6 2018 wnereiz@member.fsf.org
- Add dependency packages python3-cairo and python3-dbus-python
  (bsc#1102282)
- Some minor changes to satisfy spec-cleaner
* Sun Feb 18 2018 jengelh@inai.de
- Ensure neutrality of description.
* Sun Feb 18 2018 wnereiz@kawashiro.org
- Update to version v319, and fix .desktop file categories
* Sun Feb 12 2017 wnereiz@kawashiro.org
- Updated to version v305. There're some big changes from upstream:
  + Project home changed to github
  + Switched to python3
  + Gtk3 support
  + other minor changes
* Tue Jan 17 2017 mpluskal@suse.com
- Correct rpm group
- Enable parallel build
- Update dependencies
* Sat Jul  9 2016 wnereiz@kawashiro.org
- Remove useless python-wnck dependency (for pushing to Leap)
* Sat Jan  2 2016 mimi.vx@gmail.com
- spec-cleaned
* Fri Jun  6 2014 wnereiz <wnereiz@gmail.com>
- Remove %%clean since it is not needed anymore.
* Thu Jun  5 2014 wnereiz <wnereiz@gmail.com>
- Some changes based on rpmlint results
  + Resolve standard-dir-owned-by-package problem
  + Change GPL version to spec standard.
- Use %%_libdir instead of hardcode in spec.
* Thu Jan  2 2014 wnereiz <wnereiz@gmail.com>
- Version 208
- Build rpm form the upstream codes
